@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: BibTeX.py,v 1.17 2000/04/04 08:33:46 fredgo Exp $
+# $Id: BibTeX.py,v 1.20 2000/04/17 09:02:54 fredgo Exp $
 
 # Extension module for BibTeX files
 
@@ -36,14 +36,30 @@ _ = gettext.gettext
 # this database is shared between all the unpickled entries
 _unpickle_db = _bibtex.open_string ("<unpickled>", '', 0);
 
-_fieldtype = {
-    Text        : 2,
+_base_fieldtype = {
+    Text        : 0,
     Date        : 3,
     AuthorGroup : 1,
     URL         : 0,
     Reference   : 0,
     }
 
+_text_fieldtype = Config.get ('bibtex+/capitalize').data
+
+def _fieldtype (field):
+    if field.type is not Text:
+        return _base_fieldtype [field.type]
+
+    name = string.lower (field.name)
+    
+    if not _text_fieldtype.has_key (name):
+        return 0
+    
+    if _text_fieldtype [name]:
+        return 2
+
+    return 0
+
 
 extended_date = re.compile ('^[\{"]\s*(\d+)\s*[\}"]\s*#\s*(\w+)$')
 
@@ -150,7 +166,8 @@ class Entry (Base.Entry):
         if isinstance (value, Reference):
             value = string.join (map (lambda item: item.key, value.list), ', ')
         
-	self.dict [key] = _bibtex.reverse (_fieldtype [Types.get_field (key).type],
+	self.dict [key] = _bibtex.reverse (_fieldtype (Types.get_field (key)),
+                                           Config.get ('bibtex+/braces').data,
                                            value)
 	return
 
@@ -220,7 +237,7 @@ class Entry (Base.Entry):
 
 	return _bibtex.get_latex (self.parser,
                                   self.dict [key],
-                                  _fieldtype [Types.get_field (key).type])
+                                  _fieldtype (Types.get_field (key)))
 
 
     def field_and_loss (self, key):
@@ -233,9 +250,11 @@ class Entry (Base.Entry):
 
 	# search its declared type
 
-	fieldtype = Types.get_field (key).type
+	fieldtype = Types.get_field (key)
 	ret  = _bibtex.expand (self.parser, obj,
-                               _fieldtype [fieldtype])
+                               _fieldtype (fieldtype))
+
+        fieldtype = fieldtype.type
         
 	if fieldtype == AuthorGroup:
 	    # Author
@@ -286,7 +305,11 @@ class BibtexIterator (Iterator.Iterator):
 
 	name, fieldtype, offset, line, object = retval
 
-	key   = Key.Key (self.db, name)
+        if name:
+            key = Key.Key (self.db, name)
+        else:
+            key = None
+        
 	fieldtype  = Types.get_entry (fieldtype)
 	entry = Entry (key, fieldtype, object, self.parser, line)
 
@@ -313,7 +336,7 @@ class DataBase (Base.DataBase):
 					 Config.get ('bibtex/strict').data)
 
 	# Incorporer les definitions de l'utilisateur
-	if not Config.get ('bibtex/override').data:
+	if not Config.get ('bibtex+/override').data:
 	    user = Config.get ('bibtex/macros').data
 	    valid = re.compile ('^\w+$')
 
@@ -322,7 +345,8 @@ class DataBase (Base.DataBase):
 		    raise TypeError, _("key `%s' is malformed") % k
 
 		_bibtex.set_string (self.parser, k,
-				    _bibtex.reverse (_fieldtype [Text],
+				    _bibtex.reverse (_base_fieldtype [Text],
+                                                     Config.get ('bibtex+/braces').data,
 						     user [k] [0]))
 
 	finished = 0
@@ -331,38 +355,44 @@ class DataBase (Base.DataBase):
 	# Creer la base de cles
 	iter  = BibtexIterator (self, self.parser)
 
-        while 1:
-            # stay in the loop as long as we are on error
+        try:
+            entry = iter.first ()
+            
+            if entry.key is None:
+                self.add (entry)
+            else:
+                if self.dict.has_key (entry.key):
+                    errors.append (_("%s:%d: key `%s' already defined") % (
+                        str (self.key), entry.line, entry.key.key))
+                else:
+                    self.dict [entry.key] = entry
+        except Exceptions.ParserError, err:
+            errors.append (str (err))
+
+	while 1:
             try:
-                entry = iter.first ()
+                entry = iter.next ()
             except Exceptions.ParserError, err:
                 errors.append (str (err))
                 continue
 
-            break
-
-	while entry:
-	    if self.dict.has_key (entry.key):
-		errors.append (_("%s:%d: key `%s' already defined") % (
-			str (self.key), entry.line, entry.key.key))
-	    else:
-		self.dict [entry.key] = entry
-
-            while 1:
-                try:
-                    entry = iter.next ()
-                except IOError, err:
-                    errors.append (str (err))
-                    continue
-                
-                break
+            if entry is None: break
 
+            if entry.key is None:
+                self.add (entry)
+            else:
+                if self.dict.has_key (entry.key):
+                    errors.append (_("%s:%d: key `%s' already defined") % (
+                        str (self.key), entry.line, entry.key.key))
+                else:
+                    self.dict [entry.key] = entry
 
+        
 	if len (errors) > 0:
 	    raise Exceptions.ParserError (errors)
 
 	# Incorporer les definitions de l'utilisateur
-	if Config.get ('bibtex/override').data:
+	if Config.get ('bibtex+/override').data:
 	    user  = Config.get ('bibtex/macros').data
 	    valid = re.compile ('^\w+$')
 
@@ -371,7 +401,8 @@ class DataBase (Base.DataBase):
 		    raise TypeError, _("key `%s' is malformed") % k
 
 		_bibtex.set_string (self.parser, k,
-				    _bibtex.reverse (_fieldtype [Text],
+				    _bibtex.reverse (_base_fieldtype [Text],
+                                                     Config.get ('bibtex+/braces').data,
 						     user [k] [0]))
 	return
 
@@ -418,7 +449,8 @@ class DataBase (Base.DataBase):
 def _nativify (field, fieldtype):
     ''' private method to convert from field to native format '''
 
-    obj = _bibtex.reverse (fieldtype, field)
+    obj = _bibtex.reverse (fieldtype, Config.get ('bibtex+/braces').data,
+                           field)
     return _bibtex.get_native (obj)
 
 
@@ -483,7 +515,7 @@ def entry_write (entry, output):
 
 	    else:
 		# we are processing a normal entry
-                fieldtype = _fieldtype [Types.get_field (field).type]
+                fieldtype = _fieldtype (Types.get_field (field))
                 dico [field] = _nativify (entry [field], fieldtype)
 
 
@@ -513,7 +545,8 @@ def writer (it, output):
     <stdout> stream '''
 
     # write header
-    output.write ('% This file has been generated by Pybliographer\n\n')
+    if Config.get ('base/advertise').data:
+        output.write ('@comment{This file has been generated by Pybliographer}\n\n')
 
     # locate the entries that belong to a BibTeX database
     header = {}
