@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.15 2000/04/07 15:45:40 fredgo Exp $
+# $Id: Editor.py,v 1.16 2000/04/14 11:18:50 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -419,6 +419,8 @@ class RealEditor (Connector.Publisher):
 
         self.key = GtkEntry ()
         self.key.set_editable (TRUE)
+        self.key.connect ('key_press_event', self.key_handler)
+        
         if self.entry.key:
             self.key.set_text (self.entry.key.key)
         
@@ -488,6 +490,20 @@ class RealEditor (Connector.Publisher):
         return
 
 
+    def key_handler (self, widget, ev):
+        if ev.keyval == GDK.Return and \
+           ev.state  == GDK.CONTROL_MASK:
+            widget.emit_stop_by_name ('key_press_event')
+            self.issue ('apply')
+        
+        elif ev.keyval == GDK.Tab and \
+           ev.state  == GDK.CONTROL_MASK:
+            widget.emit_stop_by_name ('key_press_event')
+            self.issue ('next')
+
+        return 1
+
+
     def apply_cb (self, * arg):
         self.issue ('apply')
         return
@@ -645,11 +661,14 @@ class NativeEditor (Connector.Publisher):
     
 class Editor (Connector.Publisher):
     
-    def __init__ (self, database, entry, parent = None):
+    def __init__ (self, database, entry, parent = None, title = None):
         self.w = GtkDialog ()
         
         self.w.set_policy (TRUE, TRUE, FALSE)
-        self.w.set_title (_("Edit entry"))
+        
+        if title: self.w.set_title (title)
+        else:     self.w.set_title (_("Edit entry") + ' [%s]' % str (entry.key) )
+        
         self.w.connect ('delete_event', self.close_dialog)
 
         if parent: self.w.set_transient_for (parent)
