@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: reverse.c,v 1.5 2000/03/13 13:45:21 fredgo Exp $
+ $Id: reverse.c,v 1.7 2000/04/14 11:17:42 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +29,8 @@
 #include <stdbool.h>
 #else /* ! HAVE_STDBOOL_H */
 
+#include <string.h>
+
 /* stdbool.h for GNU.  */
 
 /* The type `bool' must promote to `int' or `unsigned int'.  The constants
@@ -86,7 +88,8 @@ text_to_struct (gchar * string) {
 }
 
 BibtexField * 
-bibtex_reverse_field (BibtexField * field) {
+bibtex_reverse_field (BibtexField * field,
+		      gboolean use_braces) {
 #ifdef USE_RECODE
     BibtexStruct * s;
     gchar * string, * tmp, c;
@@ -130,11 +133,29 @@ bibtex_reverse_field (BibtexField * field) {
 
 	tmp = recode_string (request, field->text);
 
-	g_string_append (st, "@preamble{{");
+	if (! use_braces) {
+	    if (strchr (tmp, '"')) {
+	        use_braces = TRUE;
+	    }
+	}
+
+	if (use_braces) {
+	    g_string_append (st, "@preamble{{");
+	}
+	else {
+	    g_string_append (st, "@preamble{\"");
+	}
+
 	g_string_append (st, tmp);
 	g_free (tmp);
-	g_string_append (st, "}}");
-	
+
+	if (use_braces) {
+	    g_string_append (st, "}}");
+	}
+	else {
+	    g_string_append (st, "\"}");
+	}
+
 	s = text_to_struct (st->str);
 	break;
 
@@ -145,23 +166,32 @@ bibtex_reverse_field (BibtexField * field) {
 	
 	tmp = recode_string (request, field->text);
 
-	g_string_append (st, "@preamble{{");
+	if (! use_braces) {
+	    if (strchr (tmp, '"')) {
+	        use_braces = TRUE;
+	    }
+	}
+
+	if (use_braces) {
+	    g_string_append (st, "@preamble{{");
+	}
+	else {
+	    g_string_append (st, "@preamble{\"");
+	}
 
 	/* Put the upper cases or the first lower cases between {} */
 	string = tmp;
 	if (* tmp >= 'a' && * tmp <= 'z') {
 	    /* Put the beginning in lower cases */
 	    g_string_append_c (st, '{');
-	    while (* tmp >= 'a' && * tmp <= 'z') {
-		g_string_append_c (st, * tmp);
-		tmp ++;
-	    }
+	    g_string_append_c (st, * tmp);
 	    g_string_append_c (st, '}');
+	    tmp ++;
 	}
 
 	is_upper = false;
 	while (* tmp) {
-	    if (* tmp >= 'A' && * tmp <= 'Z') {
+	    if (* tmp >= 'A' && * tmp <= 'Z' && (tmp > string)) {
 		if (! is_upper) {
 		    g_string_append_c (st, '{');
 		    is_upper = true;
@@ -183,7 +213,13 @@ bibtex_reverse_field (BibtexField * field) {
 	    is_upper = false;
 	}
 	g_free (string);
-	g_string_append (st, "}}");
+
+	if (use_braces) {
+	    g_string_append (st, "}}");
+	}
+	else {
+	    g_string_append (st, "\"}");
+	}
 	
 	s = text_to_struct (st->str);
 	break;
