@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: testparser.c,v 1.14 1999/09/24 07:15:47 gobry Exp $
+ $Id: testparser.c,v 1.2 2000/04/14 11:17:42 fredgo Exp $
 */
 
 #include "bibtex.h"
@@ -128,7 +128,7 @@ main (int argc, char * argv [])
 	field->text = g_strdup ("Essai \\  GRONF oui FIN");
 	field->converted = TRUE;
 	
-	field = bibtex_reverse_field (field);
+	field = bibtex_reverse_field (field, 1);
 	tmp = bibtex_struct_as_bibtex (field->structure);
 	
 	g_message ("converted: %s", tmp);
